#!/bin/bash

lastTrimDateFile="/opt/trim_documents/last_trim_date.txt"
log="/opt/trim_documents/log.txt"
dbName='documents'
dbSuffix='All'
bulkLimit=3000
srcDB=$cluster$dbName$dbSuffix

cluster="$1" 	#кластер, если КС настроен на одну сеть, то этот параметр должен быть пустым
destHost="$2" 	#хост, на котором находится БД для бэкапирования продаж
destDB="$3" 	#название БД, в которую будет производится бэкапирование продаж
destUser="$4" 	#имя пользователя MySQL, для доступа к БД для бэкапирования продаж
destPassw="$5" 	#пароль MySQL, для доступа к БД для бэкапирования продаж
days="$6" 		#количество дней, за которое необходимо оставить продажи в основной БД

tables=( "workshift" "document" "carditem" "moneyitem" "goodsitem" "stornogoodsitem" "bonusitem" "paymentitem" "discitem" "aspectitem" "button" "crights" "kkm" "securitylog" )

echo "" >> $lastTrimDateFile
lastStartTrim=$(head -n 1 $lastTrimDateFile)

let "prefixDBLen = ${#cluster} + ${#dbName}"

echo 'Last start trim at '$lastStartTrim >> $log

for t in ${tables[@]}
do
    echo $t
    # переносим из БД All все продажи старше указанного периода в другую БД
    echo "move old rows from $srcDB.$t "`pt-archiver --source h=localhost,D=$srcDB,t=$t,L=yes,u=netroot,p=netroot --where 'update_time < DATE_SUB(NOW(), INTERVAL '$days' DAY)' --charset UTF8 --dest h=$destHost,D=$destDB,t=$t,u=$destUser,p=$destPassw --statistics --bulk-insert --limit $bulkLimit --ignore` >> $log
    if [[ $lastStartTrim == "" ]]
    then
        # если запустили подрезку продаж первый раз, то копируем из БД All остальные продажи (которые моложе указанного периода) в другую БД
        echo 'First trim' >> $log
        echo "copy others rows from $srcDB.$t "`pt-archiver --source h=localhost,D=$srcDB,t=$t,L=yes,u=netroot,p=netroot --where 'update_time >= DATE_SUB(NOW(), INTERVAL '$days' DAY)' --charset UTF8 --dest h=$destHost,D=$destDB,t=$t,u=$destUser,p=$destPassw --statistics --bulk-insert --limit $bulkLimit --ignore --no-delete` >> $log
    else
        # если запустили подрезку продаж повторно, то копируем (с перезаписью) из БД All продажи которые моложе даты предыдущего запуска минус  день
        echo "copy new rows from $srcDB.$t "`pt-archiver --source h=localhost,D=$srcDB,t=$t,L=yes,u=netroot,p=netroot --where 'update_time >= DATE_SUB("'"${lastStartTrim}"'", INTERVAL 1 DAY)' --charset UTF8 --dest h=$destHost,D=$destDB,t=$t,u=$destUser,p=$destPassw --statistics --bulk-insert --limit $bulkLimit --replace --no-delete` >> $log
    fi

    # таблицу "securitylog" не обрабатываем, т.к. она присутствует только в БД All
    if [[ $t != "securitylog" ]]
    then
        for db in `mysql --user="netroot" --password="netroot" --execute="SHOW DATABASES LIKE '$cluster$dbName%';"`
            do
                # отсекаем лишние строки полученные в результате запроса получения названия баз данных
                # и не обрабатываем БД All, т.к. с этой БД работаем по другому
                if [[ ${db:0:$prefixDBLen} == $cluster$dbName && $db != $srcDB ]]
                then
                    echo $db
                    echo "remove old rows from $db.$t "`pt-archiver --source h=localhost,D=$db,t=$t,u=netroot,p=netroot --where 'update_time < DATE_SUB(NOW(), INTERVAL '$days' DAY)' --charset UTF8 --statistics --purge` >> $log
                fi
            done
    fi

done

echo "" >> $log
echo `date '+%Y-%m-%d %H:%M:%S'` > $lastTrimDateFile

exit 0